proxy — Health Dashboard

# proxy — Good

Analyzed 2026-03-25 by code2llm · Primary language: python · Python: 194, JavaScript: 85, Shell: 8, TypeScript: 1

2,218
Functions
224
Classes
249
Files
62,653
Lines
4
Languages
4.6
Avg CC
230
Critical (CC≥10)
1
Duplicates
0
Cycles

## Language Distribution

## Largest Modules (lines)

## Most Complex Modules (functions)

## Evolution

## Top Modules (288)

Module | Path | Lines | Funcs | Classes | CC max
--- | --- | --- | --- | --- | ---
tasks.jsx | src/proxym/dashboard/components | 1,697 | 110 | 0 | 129
tickets.jsx | src/proxym/dashboard/components | 1,500 | 94 | 0 | 94
projects.jsx | src/proxym/dashboard/components | 1,138 | 74 | 0 | 129
coverage_html_cb_dd2e7eb5.js | htmlcov | 735 | 65 | 0 | 21
setup.jsx | src/proxym/dashboard/components | 649 | 33 | 0 | 36
_git_support.py | src/proxym/dashboard/users | 637 | 35 | 1 | 13
environments.jsx | src/proxym/dashboard/components | 611 | 30 | 0 | 59
__init__.py | src/proxym/providers | 561 | 9 | 3 | 25
ctl.py | src/proxym | 548 | 25 | 0 | 16
validate_system.sh | scripts | 531 | 11 | 0 | 0
_tickets_api.py | src/proxym/dashboard | 526 | 21 | 0 | 11
_manager.py | src/proxym/dashboard/tickets | 508 | 34 | 1 | 28
executor.py | src/proxym/tools | 487 | 22 | 3 | 18
_environments_api.py | src/proxym/dashboard | 460 | 33 | 6 | 13
users.jsx | src/proxym/dashboard/components | 457 | 21 | 0 | 24
TicketsPanelRefactored.jsx | src/proxym/dashboard/components/tickets | 451 | 23 | 0 | 31
tickets.py | src/proxym/cli | 450 | 16 | 0 | 23
useDashboardData.js | src/proxym/dashboard/hooks | 446 | 70 | 0 | 28
events.py | src/proxym/domain | 403 | 15 | 29 | 15
__init__.py | src/proxym/accounts | 398 | 20 | 8 | 15

## Alerts (20)

Severity | Target | Type | Value | Limit
--- | --- | --- | --- | ---
critical | TasksPanel | cc_exceeded | 129 | 15
critical | ProjectFormUnified | cc_exceeded | 129 | 15
critical | TicketDetailPanel | cc_exceeded | 94 | 15
critical | TicketsPanel | cc_exceeded | 91 | 15
critical | JobDetailsPanel | cc_exceeded | 77 | 15
critical | HumanTaskPanel | cc_exceeded | 65 | 15
critical | EnvironmentsPanel | cc_exceeded | 59 | 15
critical | TicketsPanel | high_fan_out | 56 | 10
critical | useDashboardData | high_fan_out | 50 | 10
critical | ToolsJobQueue | cc_exceeded | 48 | 15
critical | TasksPanel | high_fan_out | 46 | 10
critical | TicketCard | cc_exceeded | 42 | 15
critical | TicketHistoryItem | cc_exceeded | 42 | 15
critical | EnvironmentsPanel | high_fan_out | 42 | 10
critical | DiagnosticsPanel | cc_exceeded | 40 | 15

## Hotspots (10)

Function | Fan-out | Note
--- | --- | ---
TicketsPanel | 56 | Orchestrates 56 calls
useDashboardData | 50 | Orchestrates 50 calls
TasksPanel | 46 | Orchestrates 46 calls
EnvironmentsPanel | 42 | Orchestrates 42 calls
SetupPanel | 36 | Orchestrates 36 calls
VoiceChat | 31 | Orchestrates 31 calls
ProjectFormUnified | 31 | Orchestrates 31 calls
DiagnosticsPanel | 30 | Orchestrates 30 calls
run_all_tests | 28 | Run all diagnostic tests and return comprehensive status.
chat_completions | 27 | OpenAI-compatible chat completions with intelligent routing. Extra headers: X

## Refactoring Priorities (15)

# | Action | Impact | Effort
--- | --- | --- | ---
1 | Split filter_models (CC=25 → target CC<10) | high | low
2 | Split enrich_project (CC=28 → target CC<10) | high | low
3 | Split batch_cmd (CC=25 → target CC<10) | high | low
4 | Split do_cmd (CC=26 → target CC<10) | high | low
5 | Split TicketManager._apply_filters (CC=28 → target CC<10) | high | low
6 | Split useDashboardData (CC=28 → target CC<10) | high | low
7 | Split jobToExportRow (CC=31 → target CC<10) | high | low
8 | Split DiagnosticsPanel (CC=40 → target CC<10) | high | low
9 | Split LogPanel (CC=34 → target CC<10) | high | low
10 | Split HumanTaskPanel (CC=65 → target CC<10) | high | low
11 | Split VMsPanel (CC=36 → target CC<10) | high | low
12 | Split _resolveJobEnvironment (CC=25 → target CC<10) | high | low
13 | Split TaskCardMeta (CC=37 → target CC<10) | high | low
14 | Split TaskJobBadge (CC=25 → target CC<10) | high | low
15 | Split TaskBulkEditBar (CC=30 → target CC<10) | high | low